@@ -19,7 +19,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <string>
@@ -32,9 +32,6 @@
 //=============================================================================
 // IC-7300
 
-#define isett(s) set_trace(2, s, str2hex(replystr.c_str(), replystr.length()));
-#define igett(s) get_trace(2, s, str2hex(replystr.c_str(), replystr.length()));
-
 const char IC7300name_[] = "IC-7300";
 
 // these are only defined in this file
@@ -56,11 +53,13 @@ LSBD7300, USBD7300, AMD7300, FMD7300
 };
 
 const char *IC7300modes_[] = {
-	"LSB", "USB", "AM", "FM", "CW", "CW-R", "RTTY", "RTTY-R",
+	"LSB", "USB", "AM", "FM",
+	"CW", "CW-R", "RTTY", "RTTY-R",
 	"LSB-D", "USB-D", "AM-D", "FM-D", NULL};
 
 char IC7300_mode_type[] = {
-	'L', 'U', 'U', 'U', 'L', 'U', 'L', 'U',
+	'L', 'U', 'U', 'U',
+	'L', 'U', 'L', 'U',
 	'L', 'U', 'U', 'U' };
 
 const char IC7300_mode_nbr[] = {
@@ -334,7 +333,7 @@ bool RIG_IC7300::check ()
 	return ok;
 }
 
-long RIG_IC7300::get_vfoA ()
+unsigned long int RIG_IC7300::get_vfoA ()
 {
 	string resp;
 
@@ -352,8 +351,12 @@ long RIG_IC7300::get_vfoA ()
 	cmd.append(post);
 	if (waitFOR(12, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			A.freq = fm_bcd_be(replystr.substr(p+6), 10);
+		if (p != string::npos) {
+			if (replystr[p+6] == -1)
+				A.freq = 0;
+			else
+				A.freq = fm_bcd_be(replystr.substr(p+6), 10);
+		}
 	}
 
 	igett("get_vfoA");
@@ -361,7 +364,7 @@ long RIG_IC7300::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_IC7300::set_vfoA (long freq)
+void RIG_IC7300::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 
@@ -377,7 +380,7 @@ void RIG_IC7300::set_vfoA (long freq)
 
 }
 
-long RIG_IC7300::get_vfoB ()
+unsigned long int RIG_IC7300::get_vfoB ()
 {
 	string resp;
 
@@ -395,8 +398,12 @@ long RIG_IC7300::get_vfoB ()
 	cmd.append(post);
 	if (waitFOR(12, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			B.freq = fm_bcd_be(replystr.substr(p+6), 10);
+		if (p != string::npos) {
+			if (replystr[p+6] == -1)
+				A.freq = 0;
+			else
+				B.freq = fm_bcd_be(replystr.substr(p+6), 10);
+		}
 	}
 
 	igett("get_vfoB");
@@ -404,7 +411,7 @@ long RIG_IC7300::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_IC7300::set_vfoB (long freq)
+void RIG_IC7300::set_vfoB (unsigned long int freq)
 {
 	B.freq = freq;
 
@@ -456,19 +463,22 @@ int RIG_IC7300::get_modeA()
 		if (p == string::npos)
 			goto end_wait_modeA;
 
-		for (md = 0; md < LSBD7300; md++) {
-			if (replystr[p+6] == IC7300_mode_nbr[md]) {
-				A.imode = md;
-				if (replystr[p+7] == 0x01 && A.imode < 4)
-					A.imode += 8;
-				if (A.imode > 11)
-					A.imode = 1;
-				break;
+		if (replystr[p+6] == -1) { md = A.imode = 0; }
+		else {
+			for (md = 0; md < LSBD7300; md++) {
+				if (replystr[p+6] == IC7300_mode_nbr[md]) {
+					A.imode = md;
+					if (replystr[p+7] == 0x01 && A.imode < 4)
+						A.imode += 8;
+					if (A.imode > 11)
+						A.imode = 1;
+					break;
+				}
 			}
+			A.filter = replystr[p+8];
+			if (A.filter > 0 && A.filter < 4)
+				mode_filterA[A.imode] = A.filter;
 		}
-		A.filter = replystr[p+8];
-		if (A.filter > 0 && A.filter < 4)
-			mode_filterA[A.imode] = A.filter;
 	}
 
 end_wait_modeA:
@@ -478,6 +488,7 @@ end_wait_modeA:
 	if (A.imode == CW7300 || A.imode == CWR7300) {
 		cmd.assign(pre_to).append("\x1A\x05");
 		cmd += '\x00'; cmd += '\x53';
+		cmd.append(post);
 		resp.assign(pre_fm).append("\x1A\x05");
 		resp += '\x00'; resp += '\x53';
 		if (waitFOR(10, "get CW sideband")) {
@@ -486,6 +497,7 @@ end_wait_modeA:
 			if (CW_sense) IC7300_mode_type[A.imode] = 'U';
 			else IC7300_mode_type[A.imode] = 'L';
 		}
+		get_trace(2, "get CW sideband ", str2hex(replystr.c_str(), replystr.length()));
 	}
 
 	return A.imode;
@@ -535,17 +547,20 @@ int RIG_IC7300::get_modeB()
 		if (p == string::npos)
 			goto end_wait_modeB;
 
-		for (md = 0; md < LSBD7300; md++) {
-			if (replystr[p+6] == IC7300_mode_nbr[md]) {
-				B.imode = md;
-				if (replystr[p+7] == 0x01 && B.imode < 4)
-					B.imode += 8;
-				if (B.imode > 11)
-					B.imode = 1;
-				break;
+		if (replystr[p+6] == -1) { md = filA = 0; }
+		else {
+			for (md = 0; md < LSBD7300; md++) {
+				if (replystr[p+6] == IC7300_mode_nbr[md]) {
+					B.imode = md;
+					if (replystr[p+7] == 0x01 && B.imode < 4)
+						B.imode += 8;
+					if (B.imode > 11)
+						B.imode = 1;
+					break;
+				}
 			}
+			B.filter = replystr[p+8];
 		}
-		B.filter = replystr[p+8];
 	}
 
 end_wait_modeB:
@@ -559,6 +574,7 @@ end_wait_modeB:
 	if (B.imode == CW7300 || B.imode == CWR7300) {
 		cmd.assign(pre_to).append("\x1A\x05");
 		cmd += '\x00'; cmd += '\x53';
+		cmd.append(post);
 		resp.assign(pre_fm).append("\x1A\x05");
 		resp += '\x00'; resp += '\x53';
 		if (waitFOR(10, "get CW sideband")) {
@@ -567,6 +583,7 @@ end_wait_modeB:
 			if (CW_sense) IC7300_mode_type[B.imode] = 'U';
 			else IC7300_mode_type[B.imode] = 'L';
 		}
+		get_trace(2, "get CW sideband ", str2hex(replystr.c_str(), replystr.length()));
 	}
 
 	return B.imode;
@@ -1688,8 +1705,6 @@ int RIG_IC7300::get_auto_notch()
 	return progStatus.auto_notch;
 }
 
-static bool IC7300_notchon = false;
-
 void RIG_IC7300::set_notch(bool on, int freq)
 {
 	int hexval;
@@ -1887,7 +1902,7 @@ void RIG_IC7300::set_pbt_inner(int val)
 	cmd.append("\x14\x07");
 	cmd.append(to_bcd(shift, 3));
 	cmd.append(post);
-	set_trace(4, "set_pbt_inner(", val, ") ", str2hex(cmd.c_str(), cmd.length()));
+	isett("set_pbt_inner()");
 	waitFB("set PBT inner");
 }
 
@@ -1901,7 +1916,7 @@ void RIG_IC7300::set_pbt_outer(int val)
 	cmd.append("\x14\x08");
 	cmd.append(to_bcd(shift, 3));
 	cmd.append(post);
-	set_trace(4, "set_pbt_outer(", val, ") ", str2hex(cmd.c_str(), cmd.length()));
+	isett("set_pbt_outer()");
 	waitFB("set PBT outer");
 }
 
@@ -1934,7 +1949,7 @@ int RIG_IC7300::get_pbt_outer()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	if (waitFOR(9, "get pbt inner")) {
+	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			val = num100(replystr.substr(p+6));
@@ -2010,7 +2025,7 @@ void RIG_IC7300::get_band_selection(int v)
 		igett("get band stack");
 		size_t p = replystr.rfind(pre_fm);
 		if (p != string::npos) {
-			long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -2040,7 +2055,7 @@ void RIG_IC7300::get_band_selection(int v)
 
 void RIG_IC7300::set_band_selection(int v)
 {
-	long freq = (useB ? B.freq : A.freq);
+	unsigned long int freq = (useB ? B.freq : A.freq);
 	int fil = (useB ? B.filter : A.filter);
 	int mode = (useB ? B.imode : A.imode);
 
