@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "TS480SAT.h"
@@ -1078,7 +1078,7 @@ int RIG_TS480SAT::get_split()
 	return split;
 }
 
-long RIG_TS480SAT::get_vfoA ()
+unsigned long int RIG_TS480SAT::get_vfoA ()
 {
 	cmd = "FA;";
 	if (wait_char(';', 14, 100, "get vfo A", ASC) < 14) return A.freq;
@@ -1093,7 +1093,7 @@ long RIG_TS480SAT::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_TS480SAT::set_vfoA (long freq)
+void RIG_TS480SAT::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 	cmd = "FA00000000000;";
@@ -1105,7 +1105,7 @@ void RIG_TS480SAT::set_vfoA (long freq)
 	showresp(WARN, ASC, "set vfo A", cmd, "");
 }
 
-long RIG_TS480SAT::get_vfoB ()
+unsigned long int RIG_TS480SAT::get_vfoB ()
 {
 	cmd = "FB;";
 	if (wait_char(';', 14, 100, "get vfo B", ASC) < 14) return B.freq;
@@ -1120,7 +1120,7 @@ long RIG_TS480SAT::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_TS480SAT::set_vfoB (long freq)
+void RIG_TS480SAT::set_vfoB (unsigned long int freq)
 {
 	B.freq = freq;
 	cmd = "FB00000000000;";
