@@ -70,12 +70,17 @@ status progStatus = {
 	false,		// bool aux_rts;
 	false,		// bool aux_dtr;
 
+	"12345",	// string xmlport;
+
 	"NONE",		// string	sep_serial_port;
 	false,		// bool	sep_rtsptt;
 	false,		// bool	sep_dtrptt;
 	false,		// bool	sep_rtsplus;
 	false,		// bool	sep_dtrplus;
 	false,		// bool	sep_SCU_17;
+
+	false,		// bool	disable_CW_ptt;
+
 	0,			// int	CIV;
 	false,		// bool	USBaudio;
 
@@ -107,10 +112,10 @@ status progStatus = {
 
 	-1,			// int  iBW_A;
 	1,			// int  imode_A;
-	14070000,	// long freq_A;
+	14070000,	// unsigned long int freq_A;
 	-1,			// int  iBW_B;
 	1,			// int  imode_B;
-	7070000,	// long freq_B;
+	7070000,	// unsigned long int freq_B;
 
 	"",			// std::string filters;
 	"",			// std::string bandwidths;
@@ -410,7 +415,17 @@ status progStatus = {
 	28070000L, 6, 0, 0, 0, 600,		// f10 meters
 	50070000L, 6, 0, 0, 0, 600,		// f6 meters
 	144070000L, 6, 0, 0, 0, 600,	// f2 meters
-	432100000L, 6, 0, 0, 0, 600		// f70 cent'
+	432100000L, 6, 0, 0, 0, 600,		// f70 cent'
+
+// cwio parameters
+	20,			// int    cwioWPM;
+	2,			// int    cwioKEYLINE; 1 == RTS, 2 == DTR
+	0,			// int    cwioSHARED; 0 = NONE, 1 = CAT, 2 = AUX, 3 = SEP
+	0,			// int    cwioPTT; 1 - use PTT, 0 - use Brea-in
+	0,			// int    cwioCONNECTED; 1 - connected state; 0 - unconnected state
+	0,			// double cwio_comp;
+	"",			// string cwioPORT;
+
 };
 
 void status::saveLastState()
@@ -418,7 +433,7 @@ void status::saveLastState()
 	xcvr_name = selrig->name_;
 	Fl_Preferences xcvrpref(RigHomeDir.c_str(), "w1hkj.com", PACKAGE_TARNAME);
 	xcvrpref.set("xcvr_name", xcvr_name.c_str());
-	xcvrpref.set("xml_port", xmlport);
+//	xcvrpref.set("xml_port", xmlport);
 
 	int mX = mainwindow->x();
 	int mY = mainwindow->y();
@@ -458,6 +473,9 @@ void status::saveLastState()
 	spref.set("rts_cts_flow", comm_rtscts);
 	spref.set("rts_plus", comm_rtsplus);
 	spref.set("dtr_plus", comm_dtrplus);
+
+	spref.set("disable_CW_ptt", disable_CW_ptt);
+
 	spref.set("civadr", CIV);
 	spref.set("usbaudio", USBaudio);
 
@@ -471,6 +489,8 @@ void status::saveLastState()
 	spref.set("sep_rtsplus", sep_rtsplus);
 	spref.set("set_dtrplus", sep_dtrplus);
 
+	spref.set("xmlport", xmlport.c_str());
+
 	spref.set("poll_smeter", poll_smeter);
 	spref.set("poll_frequency", poll_frequency);
 	spref.set("poll_mode", poll_mode);
@@ -496,11 +516,21 @@ void status::saveLastState()
 
 	spref.set("bw_A", iBW_A);
 	spref.set("mode_A", imode_A);
-	spref.set("freq_A", freq_A);
+
+	int freq_A_lower, freq_A_upper;
+	freq_A_upper = freq_A / 1000000000;
+	freq_A_lower = freq_A - freq_A_upper * 1000000000;
+	spref.set("freq_A_u", freq_A_upper);
+	spref.set("freq_A_l", freq_A_lower);
 
 	spref.set("bw_B", iBW_B);
 	spref.set("mode_B", imode_B);
-	spref.set("freq_B", freq_B);
+
+	int freq_B_lower, freq_B_upper;
+	freq_B_upper = freq_B / 1000000000;
+	freq_B_lower = freq_B - freq_B_upper * 1000000000;
+	spref.set("freq_B_u", freq_B_upper);
+	spref.set("freq_B_l", freq_B_lower);
 
 	spref.set("filters", filters.c_str());
 	spref.set("bandwidths", bandwidths.c_str());
@@ -837,6 +867,22 @@ void status::saveLastState()
 
 	spref.set("hrd_buttons", hrd_buttons);
 	spref.set("sliders_button", sliders_button);
+
+	spref.set("cwioWPM", cwioWPM);
+	spref.set("cwio_comp", cwio_comp);
+	spref.set("cwioKEYLINE", cwioKEYLINE);
+	spref.set("cwioSHARED", cwioSHARED);
+	spref.set("cwioPTT", cwioPTT);
+	spref.set("cwioCONNECTED", cwioCONNECTED);
+	spref.set("cwioPORT", cwioPORT.c_str());
+	char setbuff[20];
+	for (int n = 0; n < 12; n++) {
+		snprintf(setbuff, sizeof(setbuff), "cwiolabel[%d]", n);
+		spref.set(setbuff, cwio_labels[n].c_str());
+		snprintf(setbuff, sizeof(setbuff), "cwiomessage[%d]", n);
+		spref.set(setbuff, cwio_msgs[n].c_str());
+	}
+
 }
 
 bool status::loadXcvrState(string xcvr)
@@ -895,6 +941,9 @@ bool status::loadXcvrState(string xcvr)
 		if (spref.get("rts_cts_flow", i, i)) comm_rtscts = i;
 		if (spref.get("rts_plus", i, i)) comm_rtsplus = i;
 		if (spref.get("dtr_plus", i, i)) comm_dtrplus = i;
+
+		if (spref.get("disable_CW_ptt", i, i)) disable_CW_ptt = i;
+
 		spref.get("civadr", CIV, CIV);
 		if (spref.get("usbaudio", i, i)) USBaudio = i;
 
@@ -912,6 +961,10 @@ bool status::loadXcvrState(string xcvr)
 		if (spref.get("sep_rtsplus", i, i)) sep_rtsplus = i;
 		if (spref.get("sep_dtrplus", i, i)) sep_dtrplus = i;
 
+		spref.get("xmlport", defbuffer, "12345", 499);
+		xmlport = defbuffer;
+		::xmlport = atoi(xmlport.c_str());
+
 		spref.get("poll_smeter", poll_smeter, poll_smeter);
 		spref.get("poll_frequency", poll_frequency, poll_frequency);
 		spref.get("poll_mode", poll_mode, poll_mode);
@@ -937,11 +990,23 @@ bool status::loadXcvrState(string xcvr)
 
 		spref.get("bw_A", iBW_A, iBW_A);
 		spref.get("mode_A", imode_A, imode_A);
-		spref.get("freq_A", freq_A, freq_A);
+
+		int freq_A_upper = 0;
+		int freq_A_lower = 14070000;
+		spref.get("freq_A_u", freq_A_upper, freq_A_upper);
+		spref.get("freq_A_l", freq_A_lower, freq_A_lower);
+		freq_A = (unsigned long int)freq_A_upper * 1000000000 + freq_A_lower;
+std::cout << "freq A: " << freq_A << std::endl;
 
 		spref.get("bw_B", iBW_B, iBW_B);
 		spref.get("mode_B", imode_B, imode_B);
-		spref.get("freq_B", freq_B, freq_B);
+
+		int freq_B_upper = 0;
+		int freq_B_lower = 14070000;
+		spref.get("freq_B_u", freq_B_upper, freq_B_upper);
+		spref.get("freq_B_l", freq_B_lower, freq_B_lower);
+		freq_B = (unsigned long int)freq_B_upper * 1000000000 + freq_B_lower;
+std::cout << "freq B: " << freq_B << std::endl;
 
 		spref.get("filters", defbuffer, "", 499);
 		filters = defbuffer;
@@ -1338,6 +1403,24 @@ bool status::loadXcvrState(string xcvr)
 		if (spref.get("hrd_buttons", i, i)) hrd_buttons = i;
 		spref.get("sliders_button", sliders_button, sliders_button);
 
+		spref.get("cwioWPM", cwioWPM, cwioWPM);
+		spref.get("cwio_comp", cwio_comp, cwio_comp);
+		spref.get("cwioKEYLINE", cwioKEYLINE, cwioKEYLINE);
+		spref.get("cwioSHARED", cwioSHARED, cwioSHARED);
+		spref.get("cwioPTT", cwioPTT, cwioPTT);
+		spref.get("cwioCONNECTED", cwioCONNECTED, cwioCONNECTED);
+		spref.get("cwioPORT", defbuffer, "NONE", 499);
+		cwioPORT = defbuffer;
+		char getbuff[20];
+		for (int n = 0; n < 12; n++) {
+			snprintf(getbuff, sizeof(getbuff), "cwiolabel[%d]", n);
+			spref.get(getbuff, defbuffer, "", 499);
+			cwio_labels[n] = defbuffer;
+			snprintf(getbuff, sizeof(getbuff), "cwiomessage[%d]", n);
+			spref.get(getbuff, defbuffer, "", 499);
+			cwio_msgs[n] = defbuffer;
+		}
+
 		return true;
 	}
 	return false;
@@ -1356,7 +1439,7 @@ void status::loadLastState()
 		xcvrpref.get("last_xcvr_used", defbuffer, "NONE", 499);
 		xcvr_name = defbuffer;
 	}
-	xcvrpref.get("xml_port", xmlport, xmlport);
+//	xcvrpref.get("xml_port", xmlport, xmlport);
 
 	loadXcvrState(xcvr_name);
 }
